import warnings

import fabrictestbed_fablib

warnings.warn(
    "fabrictestbed_extensions.fablib.slice module is deprecated;"
    " please import fabrictestbed_fablib.slice instead",
    DeprecationWarning,
    stacklevel=2,
)

Slice = fabrictestbed_fablib.fablib.Slice



import warnings

from fabrictestbed_fablib import component

warnings.warn(
    "fabrictestbed_extensions.fablib.component module is deprecated;"
    " please import fabrictestbed_fablib.component instead",
    DeprecationWarning,
    stacklevel=2,
)

Component = fablib.Component




import warnings

import fabrictestbed_fablib

warnings.warn(
    "fabrictestbed_extensions.fablib.network_service module is deprecated;"
    " please import fabrictestbed_fablib.network_service instead",
    DeprecationWarning,
    stacklevel=2,
)

NetworkService = fabrictestbed_fablib.fablib.NetworkService



import warnings

import fabrictestbed_fablib

warnings.warn(
    "fabrictestbed_extensions.fablib.interface module is deprecated;"
    " please import fabrictestbed_fablib.interface instead",
    DeprecationWarning,
    stacklevel=2,
)

Interface = fabrictestbed_fablib.interface.Interface



import warnings

import fabrictestbed_fablib

warnings.warn(
    "fabrictestbed_extensions.fablib.facility_port module is deprecated;"
    " please import fabrictestbed_fablib.facility_port instead",
    DeprecationWarning,
    stacklevel=2,
)

FacilityPort = fabrictestbed_fablib.fablib.FacilityPort




import warnings

import fabrictestbed_fablib

warnings.warn(
    "fabrictestbed_extensions.fablib.resources module is deprecated;"
    " please import fabrictestbed_fablib.resources instead",
    DeprecationWarning,
    stacklevel=2,
)

Resources = fabrictestbed_fablib.fablib.Resources
